@@ -46,7 +46,7 @@ C
 C***********************************************************
 C     
       INTEGER K, LP, N0, NST
-      INTEGER NODES(N),IP
+      INTEGER N1, NK, NKM1, IP
       LOGICAL LEFT
 
       DO 10, IP=1,NP
@@ -65,7 +65,8 @@ C
 C     
 C     Initialization.
 C     
- 2    NODES(1) = NST
+ 2    N1 = NST
+      NK = NST
       K = 1
       N0 = NST
 C     
@@ -76,19 +77,20 @@ C
       N0 = LIST(LP)
       IF (N0 .EQ. NST) GO TO 4
       K = K + 1
-      NODES(K) = N0
+      NKM1 = NK 
+      NK = N0
 C     
 C     Check if point (X,Y) is left of the line through NODES(K-1)->NODES(K),
 C     
-      INH(IP) = INH(IP) .AND. LEFT(X(NODES(K-1)),Y(NODES(K-1)),
-     .                             X( NODES(K)),Y(NODES(K)),
+      INH(IP) = INH(IP) .AND. LEFT(X(NKM1),Y(NKM1),
+     .                             X(NK),Y(NK),
      .                             XP(IP),YP(IP))
       GO TO 3        
 C     
 C     Check if point (X,Y) is left of the line through NODES(NB)->NODES(1),
 C     
- 4    INH(IP) = INH(IP) .AND. LEFT(X(NODES(K)),Y(NODES(K)),
-     .                             X(NODES(1)),Y(NODES(1)),
+ 4    INH(IP) = INH(IP) .AND. LEFT(X(NK),Y(NK),
+     .                             X(N1),Y(N1),
      .                             XP(IP),YP(IP))
 
  10   CONTINUE
@@ -144,7 +146,7 @@ C
 C***********************************************************
 C     
       INTEGER K, LP, N0, NST
-      INTEGER NODES(N),IP
+      INTEGER N1, NK, NKM1, IP
       LOGICAL LEFT, BORDER
 
       DO 10, IP=1,NP
@@ -163,7 +165,8 @@ C
 C     
 C     Initialization.
 C     
- 2    NODES(1) = NST
+ 2    N1 = NST
+      NK = NST
       K = 1
       N0 = NST
 C     
@@ -174,19 +177,20 @@ C
       N0 = LIST(LP)
       IF (N0 .EQ. NST) GO TO 4
       K = K + 1
-      NODES(K) = N0
+      NKM1 = NK
+      NK = N0
 C     
 C     Check if point (X,Y) is left of the line through NODES(K-1)->NODES(K),
 C     
-      ONH(IP) = ONH(IP) .AND. LEFT(X(NODES(K-1)),Y(NODES(K-1)),
-     .                             X( NODES(K)),Y(NODES(K)),
+      ONH(IP) = ONH(IP) .AND. LEFT(X(NKM1),Y(NKM1),
+     .                             X(NK),Y(NK),
      .                             XP(IP),YP(IP))
       GO TO 3        
 C     
 C     Check if point (X,Y) is left of the line through NODES(NB)->NODES(1),
 C     
- 4    ONH(IP) = ONH(IP) .AND. LEFT(X(NODES(K)),Y(NODES(K)),
-     .                             X(NODES(1)),Y(NODES(1)),
+ 4    ONH(IP) = ONH(IP) .AND. LEFT(X(NK),Y(NK),
+     .                             X(N1),Y(N1),
      .                             XP(IP),YP(IP))
 
       if(ONH(IP)) then
@@ -200,7 +204,8 @@ c     IP is IN the hull, now check if it is ON the hull:
 C     
 C     Initialization.
 C     
- 12      NODES(1) = NST
+ 12      N1 = NST
+         NK = NST
          K = 1
          N0 = NST
 C     
@@ -211,19 +216,20 @@ C
          N0 = LIST(LP)
          IF (N0 .EQ. NST) GO TO 14
          K = K + 1
-         NODES(K) = N0
+         NKM1 = NK
+         NK = N0
 C     
 C     Check if point (X,Y) is on the line through NODES(K-1)->NODES(K),
 C     
-         ONH(IP) = ONH(IP) .OR. BORDER(X(NODES(K-1)),Y(NODES(K-1)),
-     .                                 X( NODES(K)),Y(NODES(K)),
+         ONH(IP) = ONH(IP) .OR. BORDER(X(NKM1),Y(NKM1),
+     .                                 X(NK),Y(NK),
      .                                 XP(IP),YP(IP))
          GO TO 13        
 C     
 C     Check if point (X,Y) is on the line through NODES(NB)->NODES(1),
 C     
- 14      ONH(IP) = ONH(IP) .OR. BORDER(X(NODES(K)),Y(NODES(K)),
-     .                                 X(NODES(1)),Y(NODES(1)),
+ 14      ONH(IP) = ONH(IP) .OR. BORDER(X(NK),Y(NK),
+     .                                 X(N1),Y(N1),
      .                                 XP(IP),YP(IP))
          
       endif
